#include "StdAfx.h"
#include "SmartEditor.h"
#include <sstream>

void CSmartEditor::NewSmartEditorDocument( long noteID )
{
	const char questionMark = '?';
	const char* ticket = "ticket";
	const char* noteSedRcvSeq = "noteSedRcvSeq";
	const char* lang = "lang";
	const char equal = '=';
	const char ampersand = '&';

	std::string strLanguage = GetLanguageString();

	const char* korean = "SmartEditor2.html";
	const char* english = "SmartEditor2_en_US.html";
	const char* japanese = "SmartEditor2_ja_JP.html";
	const char* simplifiedChinise = "SmartEditor2_zh_CN.html";
	const char* traditioanChinese = "SmartEditor2_zh_CN.html";	//  zh_TW  .

	std::string strEditorPage;
	switch( g_stNtalkInfo.nLang )
	{
	case NTALK_LANG_KOREAN:
		strEditorPage = korean;
		break;
	case NTALK_LANG_ENGLISH:
		strEditorPage = english;
		break;
	case NTALK_LANG_JAPANESE:
		strEditorPage = japanese;
		break;
	case NTALK_LANG_CHINESE_SIMPLIFIED:
		strEditorPage = simplifiedChinise;
		break;
	case NTALK_LANG_CHINESE_TRADITIONAL:
		strEditorPage = traditioanChinese;
		break;
	default:
		strEditorPage = korean;
		break;
	}

	std::stringstream strEditorPagePath;
	strEditorPagePath << CStringA(GetSmartEditorDir().GetString()) << '\\' << strEditorPage;

	std::stringstream url;
	url << strEditorPagePath.str().c_str();

	this->put_RegisterAsDropTarget(FALSE);
	CComVariant URL(url.str().c_str());
	this->Navigate2(&URL, 0, 0, 0, 0);
}

void CSmartEditor::BlankDocument()
{
	CComVariant URL(_T("about:blank"));
	this->Navigate2(&URL, 0, 0, 0, 0);
}


BOOL CSmartEditor::PreTranslateMessage(MSG* pMsg)
{
	if( pMsg->message == WM_KEYDOWN )
	{
		if(::GetAsyncKeyState(VK_CONTROL) < 0)
		{       
			if(_T('z') == (TCHAR)pMsg->wParam || _T('Z') == (TCHAR)pMsg->wParam)
			{
				SingleStepUndo();
				return TRUE;
			}

			TCHAR nChar = (TCHAR)pMsg->wParam;
			if (GetKeyState(VK_SHIFT) < 0)
			{
				if (_T('0') <= nChar && nChar <= _T('9'))
				{
					DWORD dwIndex = nChar - _T('0') + 10;	// Ctrl+Shift ε 10 
					InsertAutoText(dwIndex);
				}
			}
			else if (_T('0') <= nChar && nChar <= _T('9'))
			{
				DWORD dwIndex = nChar - _T('0');
				InsertAutoText(dwIndex);
			}
		}
	}
	return CWebBrowser2::PreTranslateMessage(pMsg);
}


void CSmartEditor::SingleStepUndo()
{
	ExecWB(OLECMDID_UNDO,NULL,NULL,NULL);
}

void CSmartEditor::InsertAutoText(DWORD dwIndex)
{
	if (dwIndex < 0 || 20 <= dwIndex)
		return;

	ReplaceSel(GET_CONFIG()->m_vecAutoText[dwIndex]);
}

void CSmartEditor::ReplaceSel( CString str )
{

	LPWSTR lpwstrCopy = 0;

	/*Smart Editer is a web browser control. 
	it handle the LF in another way. 
	it does not apply LF even copy the string from Notepad.
	So, need to translate the textIn particular: "\r\n" For Smart Editer.
	*/
	str.Replace(_T("\r\n"), _T("\r\n\r\n"));

	if(OpenClipboard())
	{
		HGLOBAL hGlobal;
		EmptyClipboard();
		hGlobal = GlobalAlloc(GMEM_MOVEABLE, (str.GetLength() + 1) * sizeof(WCHAR));
		if (hGlobal == NULL) 
		{
			CloseClipboard();
			return;
		}
		

		lpwstrCopy = (LPWSTR)GlobalLock(hGlobal);

		if (NULL != lpwstrCopy)
		{
			wcscpy_s(lpwstrCopy, str.GetLength() + 1, str.GetBuffer());
			GlobalUnlock(hGlobal); 

			SetClipboardData(CF_UNICODETEXT, hGlobal);
			CloseClipboard();
		}

		ExecWB(OLECMDID_PASTE,NULL,NULL,NULL);
	}
}

BEGIN_MESSAGE_MAP( CSmartEditor, CWebBrowser2 )
	ON_WM_KEYDOWN()
END_MESSAGE_MAP()

void CSmartEditor::OnKeyDown( UINT nChar, UINT nRepCnt, UINT nFlags )
{
	if (GetKeyState(VK_CONTROL) < 0)
	{
		if (GetKeyState(VK_SHIFT) < 0)
		{
			if (_T('0') <= nChar && nChar <= _T('9'))
			{
				DWORD dwIndex = nChar - _T('0') + 10;	// Ctrl+Shift ε 10 
				InsertAutoText(dwIndex);
			}
		}
		else if (_T('0') <= nChar && nChar <= _T('9'))
		{
			DWORD dwIndex = nChar - _T('0');
			InsertAutoText(dwIndex);
		}
	}

	CWebBrowser2::OnKeyDown(nChar, nRepCnt, nFlags);
}
